@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
 our $DATE = '2015-09-10'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 use strict;
@@ -760,13 +760,20 @@ sub list_modules {
         $_ = $re;
     }
 
+    my @mods;
+    goto NO_MODS if $httpres->content =~ /No records found/;
     return [543, "Can't scrape list of modules from response",
             $httpres->content]
         unless $httpres->content =~ m!<tr><td><b>module</b></td>.+?</tr>(.+?)</table>!s;
     my $str = $1;
-    my @mods;
+
   REC:
-    while ($str =~ m!<tr><td><a[^>]+>(.+?)</a></td>\s*<td><a[^>]+>(.+?)</a></td>\s*<td>(.+?)</td>\s*<td>(.+?)</td>\s*</tr>!gs) {
+    while ($str =~ m!<tr>
+                     <td><a[^>]+>(.+?)</a></td>\s*
+                     <td><a[^>]+>(.+?)</a></td>\s*
+                     <td>(.+?)</td>\s*
+                     <td>(.+?)</td>\s*
+                     </tr>!gsx) {
         my $rec = {module=>$1, userid=>$2, type=>$3, owner=>$4};
 
         # filter by requested file/wildcard
@@ -791,6 +798,9 @@ sub list_modules {
 
         push @mods, $args{detail} ? $rec : $rec->{module};
     }
+
+  NO_MODS:
+
     my %resmeta;
     if ($args{detail}) {
         $resmeta{format_options} = {
@@ -817,7 +827,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.26 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2015-09-10.
+This document describes version 0.27 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2015-09-10.
 
 =head1 SYNOPSIS
 
